==> owncloud-app-calendar-1%3A1.3.3-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/l10n/lt_LT.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalendorius",
    "Individual" : "Individualus",
    "Group" : "Grupė",
    "Resource" : "Išteklis",
    "Room" : "Kambarys",
    "Unknown" : "Nežinomas",
    "Required" : "Privalomas",
    "Optional" : "Neprivalomas",
    "Does not attend" : "Nedalyvauja",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Jūsų laiko juosta nežinoma ({tz}), bus naudojama UTC laiko juosta",
    "Please create a calendar first." : "Prašome pirmiau sukurti kalendorių.",
    "New event" : "Naujas įvykis",
    "Attendees" : "Dalyviai",
    "Reminders" : "Priminimai",
    "Repeating" : "Pasikartojimas",
    "Please add a title!" : "Pridėkite pavadinimą!",
    "Please select a calendar!" : "Pasirinkite kalendorių!",
    "None" : "Nieko",
    "Every day" : "Kas dieną",
    "Every week" : "Kas savaitę",
    "Every month" : "Kas mėnesį",
    "Every year" : "Kas metus",
    "never" : "niekada",
    "after" : "prieš",
    "At time of event" : "Įvykio metu",
    "5 minutes before" : "5 minutes prieš",
    "10 minutes before" : "10 minučių prieš",
    "15 minutes before" : "15 minučių prieš",
    "30 minutes before" : "30 minučių prieš",
    "1 hour before" : "1 valandą prieš",
    "2 hours before" : "2 valandas prieš",
    "Custom" : "Kitaip",
    "Audio" : "Garsu",
    "E Mail" : "El. paštu",
    "Pop up" : "Iššokančiu langu",
    "sec" : "s",
    "min" : "min",
    "hours" : "valandos",
    "days" : "dienos",
    "week" : "savaitė",
    "before" : "prieš",
    "start" : "pradžia",
    "end" : "pabaiga",
    "Editing reminders of unknown type not supported." : "Nežinomo tipo priminimų redagavimas negalimas.",
    "Week {number} of {year}" : "{year} metų {number} savaitė ",
    "Successfully imported" : "Sėkmingai importuota",
    "Partially imported, 1 failure" : "Dalinai importuota, 1 klaida",
    "Partially imported, {n} failures" : "Dalinai importuota, {n} klaidų",
    "Audio alarm" : "Gaso pranešimas",
    "Pop-up" : "Iššokantis langas",
    "E-Mail" : "El. paštas",
    "{type} {time} before the event starts" : "{type} {time} prieš įvykio pradžią",
    "{type} {time} before the event ends" : "{type} {time} prieš įvykio pabaigą",
    "{type} {time} after the event starts" : "{type} {time} po įvykio pradžios",
    "{type} {time} after the event ends" : "{type} {time} po įvykio pabaigos",
    "{type} at the event's start" : "{type} prasidedant įvykiui",
    "{type} at the event's end" : "{type} pasibaigiant įvykiui",
    "{type} at {time}" : "{type} {time}",
    "{calendar} shared by {owner}" : "{calendar} pasidalino {owner}",
    "Title of the Event" : "Įvykio pavadinimas",
    "starts" : "prasideda",
    "ends" : "baigiasi",
    "All day Event" : "Visos dienos įvykis",
    "Delete" : "Ištrinti",
    "Cancel" : "Atšaukti",
    "More ..." : "Daugiau...",
    "Create" : "Sukurti",
    "Update" : "Atnaujinti",
    "Close" : "Užverti",
    "Location" : "Vieta",
    "Description" : "Aprašymas",
    "Export" : "Eksportuoti",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Prašome susisiekti su administratoriumi ir paprašyti išjungti \"asset-pipeline.enabled\" nustatymą.",
    "Day" : "Diena",
    "Week" : "Savaitė",
    "Month" : "Mėnuo",
    "Today" : "Šiandien",
    "Share Calendar" : "Dalintis kalendoriumi",
    "Shared" : "Dalinamasi",
    "More" : "Daugiau",
    "Edit" : "Redaguoti",
    "Link" : "Nuoroda",
    "Download" : "Atsisiųsti",
    "Share with users or groups" : "Dalintis su naudotojais arba grupėmis",
    "can edit" : "gali redaguoti",
    "group" : "grupė",
    "New Calendar" : "Naujas kalendorius",
    "Subscriptions" : "Prenumeratos",
    "New Subscription" : "Nauja prenumerata",
    "Url" : "Nuoroda",
    "Edit event" : "Redaguoti įvykį",
    "Delete Event" : "Ištrinti įvykį",
    "Save Event" : "Išsaugoti įvykį",
    "Time" : "Laikas",
    "Type" : "Tipas",
    "Repeat" : "Kartoti",
    "times every" : "kartų kiekvieną",
    "Add" : "Pridėti",
    "E-Mail address of attendee" : "Dalyvaujančiųjų el. pašto adresai",
    "Please add your email address in the personal settings in order to add attendees." : "Pridėkite savo el. pašto adresą norėdami pakviesti dalyvius.",
    "from" : "iš",
    "to" : "į",
    "This event's repeating rule is not supported yet." : "Šio įvykio pasikartojimo taisyklė nepalaikoma.",
    "Support for advanced rules will be added with subsequent updates." : "Papildomų taisyklių palaikymas bus pridėtas po ateinančių atnaujinimų.",
    "Reset repeating rule" : "Atstatyti pasikartojimą",
    "Repeat every ..." : "Kartoti...",
    "end repeat ..." : "nutraukti pasikartojimą...",
    "times" : "kartus",
    "Import Calendars" : "Importuoti kalendorius",
    "Import canceled" : "Importavimas atšauktas",
    "Analyzing calendar" : "Analizuojamas kalendorius",
    "The file contains objects incompatible with the selected calendar" : "Failas turi objektų kurie nėra suderinami su pasirinktu kalendoriumi",
    "New calendar" : "Naujas kalendorius",
    "Import scheduled" : "Importavimas suplanuotas",
    "Settings" : "Parinktys",
    "Import calendar" : "Importuoti kalendorių",
    "No Calendars selected for import" : "Nepasirinktas kalendorius importavimui",
    "Primary CalDAV address" : "Pirminis CalDAV adresas",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV adresas"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> owncloud-app-calendar-1%3A1.4.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/l10n/lt_LT.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Kalendorius",
    "Individual" : "Individualus",
    "Group" : "Grupė",
    "Resource" : "Išteklis",
    "Room" : "Kambarys",
    "Unknown" : "Nežinomas",
    "Required" : "Privalomas",
    "Optional" : "Neprivalomas",
    "Does not attend" : "Nedalyvauja",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Jūsų laiko juosta ({tz}) nežinoma, bus naudojama UTC laiko juosta",
    "Please create a calendar first." : "Prašome pirmiau sukurti kalendorių.",
    "New event" : "Naujas įvykis",
    "Error saving WebCal-calendar" : "Klaida išsaugant WebCal-calendar",
    "group" : "grupė",
    "Details" : "Išsamiau",
    "Attendees" : "Dalyviai",
    "Reminders" : "Priminimai",
    "Repeating" : "Pasikartojimas",
    "Confirmed" : "Patvirtintas",
    "Cancelled" : "Atšauktas",
    "Please add a title!" : "Pridėkite pavadinimą!",
    "Please select a calendar!" : "Pasirinkite kalendorių!",
    "Global" : "Globalus",
    "None" : "Nieko",
    "Every day" : "Kas dieną",
    "Every week" : "Kas savaitę",
    "Every month" : "Kas mėnesį",
    "Every year" : "Kas metus",
    "never" : "niekada",
    "after" : "prieš",
    "At time of event" : "Įvykio metu",
    "5 minutes before" : "5 minutes prieš",
    "10 minutes before" : "10 minučių prieš",
    "15 minutes before" : "15 minučių prieš",
    "30 minutes before" : "30 minučių prieš",
    "1 hour before" : "1 valandą prieš",
    "2 hours before" : "2 valandas prieš",
    "Custom" : "Kitaip",
    "Audio" : "Garsu",
    "E Mail" : "El. paštu",
    "Pop up" : "Iššokančiu langu",
    "sec" : "s",
    "min" : "min",
    "hours" : "valandos",
    "days" : "dienos",
    "week" : "savaitė",
    "before" : "prieš",
    "start" : "pradžia",
    "end" : "pabaiga",
    "Editing reminders of unknown type not supported." : "Nežinomo tipo priminimų redagavimas negalimas.",
    "Week {number} of {year}" : "{year} metų {number} savaitė ",
    "Successfully imported" : "Sėkmingai importuota",
    "Partially imported, 1 failure" : "Dalinai importuota, 1 klaida",
    "Partially imported, {n} failures" : "Dalinai importuota, {n} klaidų",
    "Audio alarm" : "Gaso pranešimas",
    "Pop-up" : "Iššokantis langas",
    "E-Mail" : "El. paštas",
    "{type} {time} before the event starts" : "{type} {time} prieš įvykio pradžią",
    "{type} {time} before the event ends" : "{type} {time} prieš įvykio pabaigą",
    "{type} {time} after the event starts" : "{type} {time} po įvykio pradžios",
    "{type} {time} after the event ends" : "{type} {time} po įvykio pabaigos",
    "{type} at the event's start" : "{type} prasidedant įvykiui",
    "{type} at the event's end" : "{type} pasibaigiant įvykiui",
    "{type} at {time}" : "{type} {time}",
    "{calendar} shared by {owner}" : "{calendar} pasidalino {owner}",
    "Title of the Event" : "Įvykio pavadinimas",
    "starts" : "prasideda",
    "ends" : "baigiasi",
    "All day Event" : "Visos dienos įvykis",
    "Delete" : "Ištrinti",
    "Cancel" : "Atšaukti",
    "More ..." : "Daugiau...",
    "Create" : "Sukurti",
    "Update" : "Atnaujinti",
    "Close" : "Užverti",
    "Location" : "Vieta",
    "Description" : "Aprašymas",
    "Export" : "Eksportuoti",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Prašome susisiekti su administratoriumi ir paprašyti išjungti \"asset-pipeline.enabled\" nustatymą.",
    "Day" : "Diena",
    "Week" : "Savaitė",
    "Month" : "Mėnuo",
    "Today" : "Šiandien",
    "Share Calendar" : "Dalintis kalendoriumi",
    "Shared" : "Dalinamasi",
    "More" : "Daugiau",
    "Edit" : "Redaguoti",
    "Link" : "Nuoroda",
    "Download" : "Atsisiųsti",
    "Share with users or groups" : "Dalintis su naudotojais arba grupėmis",
    "can edit" : "gali redaguoti",
    "New Calendar" : "Naujas kalendorius",
    "Name" : "Pavadinimas",
    "New Subscription" : "Nauja prenumerata",
    "Go back" : "Atgal",
    "Go forward" : "Pirmyn",
    "Edit event" : "Redaguoti įvykį",
    "Delete Event" : "Ištrinti įvykį",
    "Save Event" : "Išsaugoti įvykį",
    "Time" : "Laikas",
    "Type" : "Tipas",
    "Relative" : "Santykinis",
    "Absolute" : "Absoliutus",
    "Repeat" : "Kartoti",
    "times every" : "kartų kiekvieną",
    "Add" : "Pridėti",
    "E-Mail address of attendee" : "Dalyvaujančiųjų el. pašto adresai",
    "Please add your email address in the personal settings in order to add attendees." : "Pridėkite savo el. pašto adresą norėdami pakviesti dalyvius.",
    "from" : "iš",
    "to" : "į",
    "This event's repeating rule is not supported yet." : "Šio įvykio pasikartojimo taisyklė nepalaikoma.",
    "Support for advanced rules will be added with subsequent updates." : "Papildomų taisyklių palaikymas bus pridėtas po ateinančių atnaujinimų.",
    "Reset repeating rule" : "Atstatyti pasikartojimą",
    "Repeat every ..." : "Kartoti...",
    "end repeat ..." : "nutraukti pasikartojimą...",
    "times" : "kartus",
    "Import Calendars" : "Importuoti kalendorius",
    "Import canceled" : "Importavimas atšauktas",
    "Analyzing calendar" : "Analizuojamas kalendorius",
    "The file contains objects incompatible with the selected calendar" : "Failas turi objektų kurie nėra suderinami su pasirinktu kalendoriumi",
    "New calendar" : "Naujas kalendorius",
    "Import scheduled" : "Importavimas suplanuotas",
    "Settings" : "Parinktys",
    "Import calendar" : "Importuoti kalendorių",
    "No Calendars selected for import" : "Nepasirinktas kalendorius importavimui",
    "Primary CalDAV address" : "Pirminis CalDAV adresas",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV adresas"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);");
